#!/bin/bash
#
# -- Author : François Massonnet, francois.massonnet@ic3.cat
# -- Date   : 30 Jan 2015
# -- At     : IC3, Barcelona
# -- Modified : 19 Jan 2016, omar.bellprat@bsc.es
#               1 Sept 2020 - better documentation and flexible loop_modif_restart.sh - etienne.tourigny@bsc.es
#
# -- Purpose: Generation of an arbitrary number of NEMO oceanic restarts that are copies of a reference, plus a perturbation
#
# Usage: ./loop_modif_restart.sh <expid> <timestamp>
#  e.g.: ./loop_modif_restart.sh a32m 00362336
#
# make sure that gener_perturbation.bash is in the same folder

# load the appropriate R version before calling the script
# on MN4 that can be done with "module load R/3.6.1"
# but this might work on other systems e.g. nord3 "module load R"
#module load R/3.6.1
#module load R/4.1.2-foss-2019b
#module load cray-R

load_spack
spack load netcdf-c r

SCRIPT_PATH=$(dirname "$0")

set -xuve

#a08v_20300101_000000_restart.nc

# find files to perturb based on given arguments : expid and timestep
nmemb=20
expid=$1
timestep=$2
datadir=${3:-"."}

ifiles=( $datadir/${expid}_????????_000000_restart.nc )
nfiles=${#ifiles[@]}

# Loop on all the nemo ocean restart files
for num in `seq 0 $(( $nfiles -1 ))` ; do
  file=${ifiles[$num]}
  echo $file
  ${SCRIPT_PATH}/gener_perturbation.bash $file $nmemb
  #mv `basename $file .nc`_fc0.nc $file
done

